import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FileConfig extends cdktf.TerraformMetaArguments {
    /**
    * Content to store in the file, expected to be an UTF-8 encoded string.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/file#content File#content}
    */
    readonly content?: string;
    /**
    * Content to store in the file, expected to be binary encoded as base64 string.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/file#content_base64 File#content_base64}
    */
    readonly contentBase64?: string;
    /**
    * Permissions to set for directories created (in numeric notation).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/file#directory_permission File#directory_permission}
    */
    readonly directoryPermission?: string;
    /**
    * Permissions to set for the output file (in numeric notation).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/file#file_permission File#file_permission}
    */
    readonly filePermission?: string;
    /**
    *
                      The path to the file that will be created.
                      Missing parent directories will be created.
                      If the file already exists, it will be overridden with the given content.
                  
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/file#filename File#filename}
    */
    readonly filename: string;
    /**
    * Sensitive content to store in the file, expected to be an UTF-8 encoded string.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/file#sensitive_content File#sensitive_content}
    */
    readonly sensitiveContent?: string;
    /**
    * Path to file to use as source for the one we are creating.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/file#source File#source}
    */
    readonly source?: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/local/r/file local_file}
*/
export declare class File extends cdktf.TerraformResource {
    static readonly tfResourceType = "local_file";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/local/r/file local_file} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FileConfig
    */
    constructor(scope: Construct, id: string, config: FileConfig);
    private _content?;
    get content(): string;
    set content(value: string);
    resetContent(): void;
    get contentInput(): string | undefined;
    private _contentBase64?;
    get contentBase64(): string;
    set contentBase64(value: string);
    resetContentBase64(): void;
    get contentBase64Input(): string | undefined;
    private _directoryPermission?;
    get directoryPermission(): string;
    set directoryPermission(value: string);
    resetDirectoryPermission(): void;
    get directoryPermissionInput(): string | undefined;
    private _filePermission?;
    get filePermission(): string;
    set filePermission(value: string);
    resetFilePermission(): void;
    get filePermissionInput(): string | undefined;
    private _filename?;
    get filename(): string;
    set filename(value: string);
    get filenameInput(): string | undefined;
    get id(): string;
    private _sensitiveContent?;
    get sensitiveContent(): string;
    set sensitiveContent(value: string);
    resetSensitiveContent(): void;
    get sensitiveContentInput(): string | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    resetSource(): void;
    get sourceInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=file.d.ts.map